# DataCenterRegistration


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cluster_enc_key** | **str** |  | [optional] 
**cluster_env_key** | **str** |  | [optional] 
**data_centers** | [**[DataCenter]**](DataCenter.md) |  | [optional] 
**disaster_recovery_settings** | [**DisasterRecoverySettings**](DisasterRecoverySettings.md) |  | [optional] 
**host** | [**Host**](Host.md) |  | [optional] 
**vbonds** | [**[Node]**](Node.md) |  | [optional] 
**vmanage_root_ca** | **str** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


